@@ -49,7 +49,7 @@ def _cli(target, source, signature_type, host, port, debug, dry_run):
             app = create_app(target, source, signature_type)
         elif _ctx.runtime == ASYNC:
             signature_type = "of"
-            app = create_dapr_app(target, source, signature_type, ctx)
+            app = create_dapr_app(target, source, signature_type, _ctx)
     if dry_run:
         click.echo("Function: {}".format(target))
         click.echo("URL: http://{}:{}/".format(host, port))
